@@ -1,4 +1,7 @@
+from __future__ import absolute_import
+
 import re
+from uuid import UUID
 
 from .utils import validator
 
@@ -28,6 +31,11 @@ def uuid(value):
 
     .. versionadded:: 0.2
 
-    :param value: UUID string to validate
+    :param value: UUID value to validate
     """
-    return pattern.match(value)
+    if isinstance(value, UUID):
+        return True
+    try:
+        return pattern.match(value)
+    except TypeError:
+        return False
